<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\core;

use PDO;
use PDOException;

use src\config;
use src\log\logController;
use src\log\logRepository;
use src\log\logService;
use src\server\serverController;
use src\server\serverRepository;
use src\settings\settingsController;
use src\settings\settingsRepository;
use src\tracker\trackerDataRepository;
use src\tracker\trackerDeviceController;
use src\tracker\trackerDeviceRepository;
use src\tracker\trackerModelController;
use src\tracker\trackerModelRepository;
use src\tracker\trackerService;
use src\user\loginService;
use src\user\userController;
use src\user\userRepository;

class container
{
	private $receipts = [];
	private $instance = [];
	private $configFile = [];

	public function __construct()
	{
		$this->receipts = [
			'userController' => function()
			{
				return new userController(
					$this->make("loginService"),
					$this->make("settingsRepository"),
					$this->make("trackerDataRepository"),
					$this->make("trackerDeviceRepository"),
					$this->make('userRepository')
				);
			},
			'trackerModelController' => function()
			{
				return new trackerModelController(
					$this->make("loginService"),
					$this->make('trackerModelRepository')
				);
			},
			'trackerDeviceController' => function()
			{
				return new trackerDeviceController(
					$this->make("loginService"),
					$this->make('trackerDeviceRepository'),
					$this->make('trackerModelRepository')
				);
			},
			'settingsController' => function()
			{
				return new settingsController(
					$this->make("loginService"),
					$this->make('settingsRepository')
				);
			},
			'serverController' => function()
			{
				return new serverController(
					$this->make('logRepository'),
					$this->make('logService'),
					$this->make('serverRepository'),
					$this->make('settingsRepository'),
					$this->make('trackerDataRepository'),
					$this->make('trackerDeviceRepository'),
					$this->make('trackerModelRepository'),
					$this->make('trackerService')
				);
			},
			'loginService' => function()
			{
				return new loginService(
					$this->make("settingsRepository"),
					$this->make("userRepository")
				);
			},
			'trackerService' => function()
			{
				return new trackerService(
				);
			},
			'logController' => function()
			{
				return new logController(
					$this->make("logRepository"),
					$this->make("logService"),
					$this->make("loginService"),
					$this->make("settingsRepository")
				);
			},
			'logService' => function()
			{
				return new logService(
					$this->make("logRepository")
				);
			},
			'logRepository' => function()
			{
				return new logRepository(
					$this->make("pdo")
				);
			},
			'trackerDataRepository' => function()
			{
				return new trackerDataRepository(
					$this->make("pdo")
				);
			},
			'trackerDeviceRepository' => function()
			{
				return new trackerDeviceRepository(
					$this->make("pdo")
				);
			},
			'trackerModelRepository' => function()
			{
				return new trackerModelRepository(
					$this->make("pdo")
				);
			},
			'userRepository' => function()
			{
				return new userRepository(
					$this->make("pdo")
				);
			},
			'serverRepository' => function()
			{
				return new serverRepository(
					$this->make("pdo")
				);
			},
			'settingsRepository' => function()
			{
				return new settingsRepository(
					$this->make("pdo")
				);
			},
			'pdo' => function()
			{
				$this->configFile = $this->make("config");

				try
				{
					$pdo = new PDO(
					'mysql:host='.$this->configFile->config["database"]["host"].';dbname='.$this->configFile->config["database"]["name"].';charset=utf8',
					$this->configFile->config["database"]["username"],
					$this->configFile->config["database"]["password"]
					);
				}
				catch(PDOException $e)
				{
					echo "Die Verbindung zur Datenbank ist fehlgeschlagen. $e";
					die();
				}

				$pdo->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);

				return $pdo;
			},
			'config' => function()
			{
				return new config();
			},
		];
	}

	public function make($name)
	{
		if(!empty($this->instance[$name]))
		{
			return $this->instance[$name];
		}

		if(isset($this->receipts[$name]))
		{
			$this->instance[$name] = $this->receipts[$name]();
		}

		return $this->instance[$name];
	}
}