<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\tracker;

use src\core\abstractController;
use src\user\loginService;

class trackerDeviceController extends abstractController
{
	public function __construct(
		loginService $loginService,
		trackerDeviceRepository $trackerDeviceRepository,
		trackerModelRepository $trackerModelRepository
	)
	{
		$this->loginService = $loginService;
		$this->trackerDeviceRepository = $trackerDeviceRepository;
		$this->trackerModelRepository = $trackerModelRepository;
	}

	public function trackersDevice()
	{
		$this->loginService->checkLoggedIn();

		$all = $this->trackerDeviceRepository->all();

		$this->render("tracker/trackersDevice", [
			'all' => $all
		]);
	}

 	public function trackerDeviceEdit()
	{
		$this->loginService->checkLoggedIn();

 		$id = $_GET['id'];
 		$saved[2] = $_GET['saved2'];

		$entry = $this->trackerDeviceRepository->findById($id);

		$saved[1] = false;

		if(!empty($_POST["delete"]))
		{
			$entry = $this->trackerDeviceRepository->deleteById($id);

			header("Location: ".BASE_URL."/trackers/device?delete=true");
			return;
		}

		if(!empty($_POST["save"]))
		{
			$entry["name"] = $_POST["name"];
			$entry["imei"] = $_POST["imei"];
			$entry["phoneNumber"] = $_POST["phoneNumber"];
			$entry["trackerModelId"] = $_POST["trackerModelId"];
			$entry["function"] = $_POST["function"];
			$entry["status"] = $_POST["status"];

			if(empty($entry["name"]))
				$errorCode[1] = 'name';

			if(empty($entry["imei"]))
				$errorCode[2] = 'imei';

			if(empty($entry["trackerModelId"]))
				$errorCode[3] = 'trackerModelId';

			if(!empty($entry["phoneNumber"]) and !is_numeric($entry["phoneNumber"]))
				$errorCode[4] = 'phoneNumberNumeric';

			if(!isset($errorCode))
			{
				$this->trackerDeviceRepository->update($entry);

				$saved[1] = true;
			}
		}

		$trackerModel = $this->trackerModelRepository->all();

		$this->render("tracker/trackerDeviceEdit", [
			'entry' => $entry,
			'trackerModel' => $trackerModel,
			'errorCode' => $errorCode,
			'saved' => $saved
		]);
	}

	public function trackerDeviceNew()
	{
		$this->loginService->checkLoggedIn();

		if($_POST)
		{
			$entry["id"] = $_POST["id"];
			$entry["name"] = $_POST["name"];
			$entry["imei"] = $_POST["imei"];
			$entry["phoneNumber"] = $_POST["phoneNumber"];
			$entry["trackerModelId"] = $_POST["trackerModelId"];
			$entry["function"] = $_POST["function"];
			$entry["status"] = $_POST["status"];
			$entry["userId"] = $_SESSION["loginUID"];

 			if(empty($entry["name"]))
				$errorCode[1] = 'name';

			if(empty($entry["imei"]))
				$errorCode[2] = 'imei';

			if(empty($entry["trackerModelId"]))
				$errorCode[3] = 'trackerModelId';

			if(!empty($entry["phoneNumber"]) and !is_numeric($entry["phoneNumber"]))
				$errorCode[4] = 'phoneNumberNumeric';

			if(!isset($errorCode))
			{
				$id = $this->trackerDeviceRepository->insert(
					$entry["name"],
					$entry["imei"],
					$entry["phoneNumber"],
					$entry["trackerModelId"],
					$entry["function"],
					$entry["status"],
					$entry["userId"]
				);

				if($id)
				{
					header("Location: ".BASE_URL."/trackers/device/edit?id=".$id."&saved2=true");
					return;
				}
			}
		}

		$trackerModel = $this->trackerModelRepository->all();

		$this->render("tracker/trackerDeviceEdit", [
			'entry' => $entry,
			'trackerModel' => $trackerModel,
			'errorCode' => $errorCode
		]);
	}
}
?>