<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\tracker;

use src\core\abstractController;
use src\user\loginService;

class trackerModelController extends abstractController
{
	public function __construct(
		loginService $loginService,
		trackerModelRepository $trackerModelRepository
	)
	{
		$this->loginService = $loginService;
		$this->trackerModelRepository = $trackerModelRepository;
	}

	public function trackersModel()
	{
		$this->loginService->checkLoggedIn();

		$all = $this->trackerModelRepository->all();

		$this->render("tracker/trackersModel", [
			'all' => $all
		]);
	}

 	public function trackerModelEdit()
	{
		$this->loginService->checkLoggedIn();

 		$id = $_GET['id'];
 		$saved[2] = $_GET['saved2'];

		$entry = $this->trackerModelRepository->findById($id);

		$saved[1] = false;

		if(!empty($_POST["delete"]))
		{
			$entry = $this->trackerModelRepository->deleteById($id);

			header("Location: ".BASE_URL."/trackers/model?delete=true");
			return;
		}

		if(!empty($_POST["save"]))
		{
			$entry["id"] = $_POST["id"];
			$entry["name"] = $_POST["name"];
			$entry["port"] = $_POST["port"];
			$entry["protocol"] = $_POST["protocol"];
			$entry["pattern"] = $_POST["pattern"];
			$entry["imeiPosition"] = $_POST["imeiPosition"];
			$entry["timeHourPosition"] = $_POST["timeHourPosition"];
			$entry["timeMinutePosition"] = $_POST["timeMinutePosition"];
			$entry["timeSecondPosition"] = $_POST["timeSecondPosition"];
			$entry["timeDayPosition"] = $_POST["timeDayPosition"];
			$entry["timeMonthPosition"] = $_POST["timeMonthPosition"];
			$entry["timeYearPosition"] = $_POST["timeYearPosition"];
			$entry["timeFunction"] = $_POST["timeFunction"];
			$entry["statusPosition"] = $_POST["statusPosition"];
			$entry["statusFunction"] = ' '; //$_POST["statusFunction"];
			$entry["coordinatesBPosition"] = $_POST["coordinatesBPosition"];
			$entry["coordinatesNSPosition"] = $_POST["coordinatesNSPosition"];
			$entry["coordinatesBFunction"] = $_POST["coordinatesBFunction"];
			$entry["coordinatesLPosition"] = $_POST["coordinatesLPosition"];
			$entry["coordinatesEWPosition"] = $_POST["coordinatesEWPosition"];
			$entry["coordinatesLFunction"] = $_POST["coordinatesLFunction"];
			$entry["speedPosition"] = $_POST["speedPosition"];
			$entry["speedFunction"] = $_POST["speedFunction"];
			$entry["directionPosition"] = $_POST["directionPosition"];
			$entry["directionFunction"] = ' '; //$_POST["directionFunction"];
			$entry["eventPosition"] = $_POST["eventPosition"];
			$entry["eventFunction"] = ' '; //$_POST["eventFunction"];
			$entry["voltagePosition"] = $_POST["voltagePosition"];
			$entry["voltagePercentPosition"] = $_POST["voltagePercentPosition"];

			if(empty($entry["name"]))
				$errorCode[1] = 'name';

			if(empty($entry["port"]))
				$errorCode[2] = 'port';

			$trackerModel = $this->trackerModelRepository->findByPort($entry["port"]);

			if($entry["id"] != $trackerModel["id"] and !empty($trackerModel))
				$errorCode[28] = 'portexists';

			if(empty($entry["pattern"]))
				$errorCode[3] = 'pattern';

			if(empty($entry["imeiPosition"]))
				$errorCode[4] = 'imeiPosition';

			if(empty($entry["timeHourPosition"]))
				$errorCode[5] = 'timeHourPosition';

			if(empty($entry["timeMinutePosition"]))
				$errorCode[6] = 'timeMinutePosition';

			if(empty($entry["timeSecondPosition"]))
				$errorCode[7] = 'timeSecondPosition';

			if(empty($entry["timeDayPosition"]))
				$errorCode[8] = 'timeDayPosition';

			if(empty($entry["timeMonthPosition"]))
				$errorCode[9] = 'timeMonthPosition';

			if(empty($entry["timeYearPosition"]))
				$errorCode[10] = 'timeYearPosition';

			if(empty($entry["timeFunction"]))
				$errorCode[11] = 'timeFunction';

			if(empty($entry["statusPosition"]))
				$errorCode[12] = 'statusPosition';

			// if(empty($entry["statusFunction"]))
				// $errorCode[13] = 'statusFunction';

			if(empty($entry["coordinatesBPosition"]))
				$errorCode[14] = 'coordinatesBPosition';

			if(empty($entry["coordinatesNSPosition"]))
				$errorCode[15] = 'coordinatesNSPosition';

			if(empty($entry["coordinatesBFunction"]))
				$errorCode[16] = 'coordinatesBFunction';

			if(empty($entry["coordinatesLPosition"]))
				$errorCode[17] = 'coordinatesLPosition';

			if(empty($entry["coordinatesEWPosition"]))
				$errorCode[18] = 'coordinatesEWPosition';

			if(empty($entry["coordinatesLFunction"]))
				$errorCode[19] = 'coordinatesLFunction';

			if(empty($entry["speedPosition"]))
				$errorCode[20] = 'speedPosition';

			if(empty($entry["speedFunction"]))
				$errorCode[21] = 'speedFunction';

			if(empty($entry["directionPosition"]))
				$errorCode[22] = 'directionPosition';

			// if(empty($entry["directionFunction"]))
				// $errorCode[23] = 'directionFunction';

			if(empty($entry["eventPosition"]))
				$errorCode[24] = 'eventPosition';

			// if(empty($entry["eventFunction"]))
				// $errorCode[25] = 'eventFunction';

			if(empty($entry["voltagePosition"]))
				$errorCode[26] = 'voltagePosition';

			if(empty($entry["voltagePercentPosition"]))
				$errorCode[27] = 'voltagePercentPosition';

			if(!isset($errorCode))
			{
				$this->trackerModelRepository->update($entry);

				$saved[1] = true;
			}
		}

		$this->render("tracker/trackerModelEdit", [
			'entry' => $entry,
			'errorCode' => $errorCode,
			'saved' => $saved
		]);
	}

	public function trackerModelNew()
	{
		$this->loginService->checkLoggedIn();

		if($_POST)
		{
			$entry["name"] = $_POST["name"];
			$entry["port"] = $_POST["port"];
			$entry["protocol"] = $_POST["protocol"];
			$entry["pattern"] = $_POST["pattern"];
			$entry["imeiPosition"] = $_POST["imeiPosition"];
			$entry["timeHourPosition"] = $_POST["timeHourPosition"];
			$entry["timeMinutePosition"] = $_POST["timeMinutePosition"];
			$entry["timeSecondPosition"] = $_POST["timeSecondPosition"];
			$entry["timeDayPosition"] = $_POST["timeDayPosition"];
			$entry["timeMonthPosition"] = $_POST["timeMonthPosition"];
			$entry["timeYearPosition"] = $_POST["timeYearPosition"];
			$entry["timeFunction"] = $_POST["timeFunction"];
			$entry["statusPosition"] = $_POST["statusPosition"];
			$entry["statusFunction"] = ' '; //$_POST["statusFunction"];
			$entry["coordinatesBPosition"] = $_POST["coordinatesBPosition"];
			$entry["coordinatesNSPosition"] = $_POST["coordinatesNSPosition"];
			$entry["coordinatesBFunction"] = $_POST["coordinatesBFunction"];
			$entry["coordinatesLPosition"] = $_POST["coordinatesLPosition"];
			$entry["coordinatesEWPosition"] = $_POST["coordinatesEWPosition"];
			$entry["coordinatesLFunction"] = $_POST["coordinatesLFunction"];
			$entry["speedPosition"] = $_POST["speedPosition"];
			$entry["speedFunction"] = $_POST["speedFunction"];
			$entry["directionPosition"] = $_POST["directionPosition"];
			$entry["directionFunction"] = ' '; //$_POST["directionFunction"];
			$entry["eventPosition"] = $_POST["eventPosition"];
			$entry["eventFunction"] = ' '; //$_POST["eventFunction"];
			$entry["voltagePosition"] = $_POST["voltagePosition"];
			$entry["voltagePercentPosition"] = $_POST["voltagePercentPosition"];

 			if(empty($entry["name"]))
				$errorCode[1] = 'name';

			if(empty($entry["port"]))
				$errorCode[2] = 'port';

			$trackerModel = $this->trackerModelRepository->findByPort($entry["port"]);

			if(!empty($trackerModel))
				$errorCode[28] = 'portexists';

			if(empty($entry["pattern"]))
				$errorCode[3] = 'pattern';

			if(empty($entry["imeiPosition"]))
				$errorCode[4] = 'imeiPosition';

			if(empty($entry["timeHourPosition"]))
				$errorCode[5] = 'timeHourPosition';

			if(empty($entry["timeMinutePosition"]))
				$errorCode[6] = 'timeMinutePosition';

			if(empty($entry["timeSecondPosition"]))
				$errorCode[7] = 'timeSecondPosition';

			if(empty($entry["timeDayPosition"]))
				$errorCode[8] = 'timeDayPosition';

			if(empty($entry["timeMonthPosition"]))
				$errorCode[9] = 'timeMonthPosition';

			if(empty($entry["timeYearPosition"]))
				$errorCode[10] = 'timeYearPosition';

			if(empty($entry["timeFunction"]))
				$errorCode[11] = 'timeFunction';

			if(empty($entry["statusPosition"]))
				$errorCode[12] = 'statusPosition';

			// if(empty($entry["statusFunction"]))
				// $errorCode[13] = 'statusFunction';

			if(empty($entry["coordinatesBPosition"]))
				$errorCode[14] = 'coordinatesBPosition';

			if(empty($entry["coordinatesNSPosition"]))
				$errorCode[15] = 'coordinatesNSPosition';

			if(empty($entry["coordinatesBFunction"]))
				$errorCode[16] = 'coordinatesBFunction';

			if(empty($entry["coordinatesLPosition"]))
				$errorCode[17] = 'coordinatesLPosition';

			if(empty($entry["coordinatesEWPosition"]))
				$errorCode[18] = 'coordinatesEWPosition';

			if(empty($entry["coordinatesLFunction"]))
				$errorCode[19] = 'coordinatesLFunction';

			if(empty($entry["speedPosition"]))
				$errorCode[20] = 'speedPosition';

			if(empty($entry["speedFunction"]))
				$errorCode[21] = 'speedFunction';

			if(empty($entry["directionPosition"]))
				$errorCode[22] = 'directionPosition';

			// if(empty($entry["directionFunction"]))
				// $errorCode[23] = 'directionFunction';

			if(empty($entry["eventPosition"]))
				$errorCode[24] = 'eventPosition';

			// if(empty($entry["eventFunction"]))
				// $errorCode[25] = 'eventFunction';

			if(empty($entry["voltagePosition"]))
				$errorCode[26] = 'voltagePosition';

			if(empty($entry["voltagePercentPosition"]))
				$errorCode[27] = 'voltagePercentPosition';

			if(!isset($errorCode))
			{
				$id = $this->trackerModelRepository->insert(
					$entry["name"],
					$entry["port"],
					$entry["protocol"],
					$entry["pattern"],
					$entry["imeiPosition"],
					$entry["timeHourPosition"],
					$entry["timeMinutePosition"],
					$entry["timeSecondPosition"],
					$entry["timeDayPosition"],
					$entry["timeMonthPosition"],
					$entry["timeYearPosition"],
					$entry["timeFunction"],
					$entry["statusPosition"],
					$entry["statusFunction"],
					$entry["coordinatesBPosition"],
					$entry["coordinatesNSPosition"],
					$entry["coordinatesBFunction"],
					$entry["coordinatesLPosition"],
					$entry["coordinatesEWPosition"],
					$entry["coordinatesLFunction"],
					$entry["speedPosition"],
					$entry["speedFunction"],
					$entry["directionPosition"],
					$entry["directionFunction"],
					$entry["eventPosition"],
					$entry["eventFunction"],
					$entry["voltagePosition"],
					$entry["voltagePercentPosition"]
				);

				if($id)
				{
					header("Location: ".BASE_URL."/trackers/model/edit?id=".$id."&saved2=true");
					return;
				}
			}
		}

		$this->render("tracker/trackerModelEdit", [
			'entry' => $entry,
			'errorCode' => $errorCode
		]);
	}
}
?>