<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\tracker;

use PDO;

use src\core\abstractRepository;


class trackerModelRepository extends abstractRepository
{
	public function getModelName()
	{
		return "src\\tracker\\trackerModelModel";
	}

	public function getTableName()
	{
		return "trackerModel";
	}

	public function findByPort($port)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE port = :port");
		$stmt->execute(['port' => $port]);
		$stmt->setFetchMode(PDO::FETCH_CLASS, $model);
		$user = $stmt->fetch(PDO::FETCH_CLASS);

		return $user;
	}

	public function update(trackerModelModel $model)
	{
 		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"UPDATE `$table` SET
				`name` = :name,
				`port` = :port,
				`protocol` = :protocol,
				`pattern` = :pattern,
				`imeiPosition` = :imeiPosition,
				`timeHourPosition` = :timeHourPosition,
				`timeMinutePosition` = :timeMinutePosition,
				`timeSecondPosition` = :timeSecondPosition,
				`timeDayPosition` = :timeDayPosition,
				`timeMonthPosition` = :timeMonthPosition,
				`timeYearPosition` = :timeYearPosition,
				`timeFunction` = :timeFunction,
				`statusPosition` = :statusPosition,
				`statusFunction` = :statusFunction,
				`coordinatesBPosition` = :coordinatesBPosition,
				`coordinatesNSPosition` = :coordinatesNSPosition,
				`coordinatesBFunction` = :coordinatesBFunction,
				`coordinatesLPosition` = :coordinatesLPosition,
				`coordinatesEWPosition` = :coordinatesEWPosition,
				`coordinatesLFunction` = :coordinatesLFunction,
				`speedPosition` = :speedPosition,
				`speedFunction` = :speedFunction,
				`directionPosition` = :directionPosition,
				`directionFunction` = :directionFunction,
				`eventPosition` = :eventPosition,
				`eventFunction` = :eventFunction,
				`voltagePosition` = :voltagePosition,
				`voltagePercentPosition` = :voltagePercentPosition

				WHERE `id` = :id"
			);

		$stmt->execute([
			'id' => $model->id,
			'name' => $model->name,
			'port' => $model->port,
			'protocol' => $model->protocol,
			'pattern' => $model->pattern,
			'imeiPosition' => $model->imeiPosition,
			'timeHourPosition' => $model->timeHourPosition,
			'timeMinutePosition' => $model->timeMinutePosition,
			'timeSecondPosition' => $model->timeSecondPosition,
			'timeDayPosition' => $model->timeDayPosition,
			'timeMonthPosition' => $model->timeMonthPosition,
			'timeYearPosition' => $model->timeYearPosition,
			'timeFunction' => $model->timeFunction,
			'statusPosition' => $model->statusPosition,
			'statusFunction' => $model->statusFunction,
			'coordinatesBPosition' => $model->coordinatesBPosition,
			'coordinatesNSPosition' => $model->coordinatesNSPosition,
			'coordinatesBFunction' => $model->coordinatesBFunction,
			'coordinatesLPosition' => $model->coordinatesLPosition,
			'coordinatesEWPosition' => $model->coordinatesEWPosition,
			'coordinatesLFunction' => $model->coordinatesLFunction,
			'speedPosition' => $model->speedPosition,
			'speedFunction' => $model->speedFunction,
			'directionPosition' => $model->directionPosition,
			'directionFunction' => $model->directionFunction,
			'eventPosition' => $model->eventPosition,
			'eventFunction' => $model->eventFunction,
			'voltagePosition' => $model->voltagePosition,
			'voltagePercentPosition' => $model->voltagePercentPosition
		]);
	}

	public function insert($name, $port, $protocol, $pattern, $imeiPosition, $timeHourPosition, $timeMinutePosition, $timeSecondPosition, $timeDayPosition, $timeMonthPosition, $timeYearPosition, $timeFunction, $statusPosition, $statusFunction, $coordinatesBPosition, $coordinatesNSPosition, $coordinatesBFunction, $coordinatesLPosition, $coordinatesEWPosition, $coordinatesLFunction, $speedPosition, $speedFunction, $directionPosition, $directionFunction, $eventPosition, $eventFunction, $voltagePosition, $voltagePercentPosition)
	{
		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"INSERT INTO `$table` (
				`name`,
				`port`,
				`protocol`,
				`pattern`,
				`imeiPosition`,
				`timeHourPosition`,
				`timeMinutePosition`,
				`timeSecondPosition`,
				`timeDayPosition`,
				`timeMonthPosition`,
				`timeYearPosition`,
				`timeFunction`,
				`statusPosition`,
				`statusFunction`,
				`coordinatesBPosition`,
				`coordinatesNSPosition`,
				`coordinatesBFunction`,
				`coordinatesLPosition`,
				`coordinatesEWPosition`,
				`coordinatesLFunction`,
				`speedPosition`,
				`speedFunction`,
				`directionPosition`,
				`directionFunction`,
				`eventPosition`,
				`eventFunction`,
				`voltagePosition`,
				`voltagePercentPosition`
			)
			VALUES (
				:name,
				:port,
				:protocol,
				:pattern,
				:imeiPosition,
				:timeHourPosition,
				:timeMinutePosition,
				:timeSecondPosition,
				:timeDayPosition,
				:timeMonthPosition,
				:timeYearPosition,
				:timeFunction,
				:statusPosition,
				:statusFunction,
				:coordinatesBPosition,
				:coordinatesNSPosition,
				:coordinatesBFunction,
				:coordinatesLPosition,
				:coordinatesEWPosition,
				:coordinatesLFunction,
				:speedPosition,
				:speedFunction,
				:directionPosition,
				:directionFunction,
				:eventPosition,
				:eventFunction,
				:voltagePosition,
				:voltagePercentPosition
			)"
		);

		$stmt->execute([
			'name' => $name,
			'port' => $port,
			'protocol' => $protocol,
			'pattern' => $pattern,
			'imeiPosition' => $imeiPosition,
			'timeHourPosition' => $timeHourPosition,
			'timeMinutePosition' => $timeMinutePosition,
			'timeSecondPosition' => $timeSecondPosition,
			'timeDayPosition' => $timeDayPosition,
			'timeMonthPosition' => $timeMonthPosition,
			'timeYearPosition' => $timeYearPosition,
			'timeFunction' => $timeFunction,
			'statusPosition' => $statusPosition,
			'statusFunction' => $statusFunction,
			'coordinatesBPosition' => $coordinatesBPosition,
			'coordinatesNSPosition' => $coordinatesNSPosition,
			'coordinatesBFunction' => $coordinatesBFunction,
			'coordinatesLPosition' => $coordinatesLPosition,
			'coordinatesEWPosition' => $coordinatesEWPosition,
			'coordinatesLFunction' => $coordinatesLFunction,
			'speedPosition' => $speedPosition,
			'speedFunction' => $speedFunction,
			'directionPosition' => $directionPosition,
			'directionFunction' => $directionFunction,
			'eventPosition' => $eventPosition,
			'eventFunction' => $eventFunction,
			'voltagePosition' => $voltagePosition,
			'voltagePercentPosition' => $voltagePercentPosition
		]);

		return $this->pdo->lastInsertId();
	}
}
?>