<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\user;

use src\settings\settingsRepository;

class loginService
{
	public function __construct(
		settingsRepository $settingsRepository,
		userRepository $userRepository
	)
	{
		$this->settingsRepository = $settingsRepository;
		$this->userRepository = $userRepository;
	}

	public function checkLoggedIn()
	{
		if(isset($_SESSION['loginUID']))
		{
			$settings = $this->settingsRepository->all();
			$_SESSION['loginTime'] = $settings[0]->loginTime;

			$user = $this->userRepository->findById($_SESSION['loginUID']);
			$user->lastactivity = time();
			$this->userRepository->update($user);

			return true;
		}
		else
		{
			header("Location: ".BASE_URL."/");
			die();
		}
	}

	public function loginCheck($username, $password)
	{
		$user = $this->userRepository->findByUsername($username);
		$settings = $this->settingsRepository->all();

		if(empty($user))
		{
			return "ErrorCode1";
		}

		if($user->trylogin >= $settings[0]->loginTrys)
		{
			$user->trylogin = $user->trylogin + 1;
			$this->userRepository->update($user);

			return "ErrorCode2";
		}

		if(password_verify($password, $user->password))
		{
			$_SESSION['loginUID'] = $user->id;

			$user->trylogin = 0;
			$user->lastactivity = time();
			$user->loginbefore = $user->lastlogin;
			$user->lastlogin = time();
			$this->userRepository->update($user);

			session_regenerate_id(true);

			return true;
		}
		else
		{
			$user->trylogin = $user->trylogin + 1;
			$this->userRepository->update($user);

			return "ErrorCode1";
		}
	}

	public function logout()
	{
		if($_SESSION)
		{
			$user = $this->userRepository->findById($_SESSION['loginUID']);
			$user->lastactivity = '0';
			$this->userRepository->update($user);
		}

		session_unset();
		session_regenerate_id(true);
	}
}
?>